@@ -1,3 +1,5 @@
+import os
+from .noop_traceid import NoOpTraceId
 from .traceid import TraceId
 from .segment import Segment
 from .subsegment import Subsegment
@@ -12,9 +14,13 @@ class DummySegment(Segment):
     A dummy segment will not be sent to the X-Ray daemon. Manually create
     dummy segments is not recommended.
     """
-    def __init__(self, name='dummy'):
 
-        super(DummySegment, self).__init__(name=name, traceid=TraceId().to_id())
+    def __init__(self, name='dummy'):
+        no_op_id = os.getenv('AWS_XRAY_NOOP_ID')
+        if no_op_id and no_op_id.lower() == 'false':
+            super(DummySegment, self).__init__(name=name, traceid=TraceId().to_id())
+        else:
+            super(DummySegment, self).__init__(name=name, traceid=NoOpTraceId().to_id(), entityid='0000000000000000')
         self.sampled = False
 
     def set_aws(self, aws_meta):
@@ -79,9 +85,14 @@ class DummySubsegment(Subsegment):
     to a dummy subsegment becomes no-op. Dummy subsegment will not
     be sent to the X-Ray daemon.
     """
-    def __init__(self, segment, name='dummy'):
 
+    def __init__(self, segment, name='dummy'):
         super(DummySubsegment, self).__init__(name, 'dummy', segment)
+        no_op_id = os.getenv('AWS_XRAY_NOOP_ID')
+        if no_op_id and no_op_id.lower() == 'false':
+            super(Subsegment, self).__init__(name)
+        else:
+            super(Subsegment, self).__init__(name, entity_id='0000000000000000')
         self.sampled = False
 
     def set_aws(self, aws_meta):
