@@ -1,4 +1,6 @@
 import re
+import types
+
 from aws_xray_sdk.core import xray_recorder
 from aws_xray_sdk.ext.util import strip_url
 from future.standard_library import install_aliases
@@ -13,7 +15,7 @@ def decorate_all_functions(function_decorator):
             for name, obj in vars(c).items():
                 if name.startswith("_"):
                     continue
-                if callable(obj):
+                if isinstance(obj, types.FunctionType):
                     try:
                         obj = obj.__func__  # unwrap Python 2 unbound method
                     except AttributeError:
